# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.1] - 2026-02-06

### Added
- AMSDAL End User License Agreement

## [0.2.0] - 2026-02-06

### Changed
- Upgraded to amsdal v0.6.0

## [0.1.0] - 2025-10-15

### Added
- Implemented AmsdalCheckpointSaver for LangGraph checkpoint persistence